@@ -23,9 +23,11 @@ def getAwsInstanceDetails(config, authentication_token, account_id, host, log, d
 
     metadata_token_url = config['aws_metadata_service_token_url']
     aws_token = _fetch_aws_metadata_token(metadata_token_url, log)
-    
+    log.info("token {}".format(aws_token))
+
     locator_url = config['aws_instance_id_locator_url']
     instance_id = getAwsInstanceId(locator_url, log, token=aws_token)
+    log.info("instance id {}".format(instance_id))
     if instance_id and authentication_token:
         instance_details = {'cloud_provider': 'AWS', 'instance_id': instance_id,
                             'authentication_token': authentication_token,
